@@ -8,7 +8,7 @@
 #include "playerApplication.h"
 #include "mainWindow.h"
 
-#include <KWindowSystem>
+#include <KX11Extras>
 
 namespace Dragon
 {
@@ -34,9 +34,7 @@ void PlayerApplication::slotActivateRequested(const QStringList &arguments, cons
         newInstance(true);
         forceActiveWindow();
     } else if (arguments.count() == 2) { // 1st arg binary name, 2nd arg file to open
-        QUrl url = QUrl::fromUserInput(arguments.at(1),
-                                       workingDirectory,
-                                       QUrl::AssumeLocalFile);
+        QUrl url = QUrl::fromUserInput(arguments.at(1), workingDirectory, QUrl::AssumeLocalFile);
         newInstance(false, {url});
         forceActiveWindow();
     }
@@ -51,7 +49,7 @@ void PlayerApplication::slotOpenRequested(const QList<QUrl> &uris)
 
 void PlayerApplication::forceActiveWindow()
 {
-    KWindowSystem::forceActiveWindow(Dragon::mainWindow()->winId());
+    KX11Extras::forceActiveWindow(Dragon::mainWindow()->winId());
 }
 
 void PlayerApplication::newInstance(bool playDisc, const QList<QUrl> &uris)
